Term
====

.. currentmodule:: pyobo

.. autoclass:: Term
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Term.definition
      ~Term.is_obsolete
      ~Term.namespace

   .. rubric:: Methods Summary

   .. autosummary::

      ~Term.append_alt
      ~Term.append_comment
      ~Term.append_exact_match
      ~Term.append_parent
      ~Term.append_property
      ~Term.append_provenance
      ~Term.append_relationship
      ~Term.append_see_also
      ~Term.append_synonym
      ~Term.append_xref
      ~Term.auto
      ~Term.extend_parents
      ~Term.extend_relationship
      ~Term.from_curie
      ~Term.from_triple
      ~Term.get_properties
      ~Term.get_property
      ~Term.get_relationship
      ~Term.get_relationships
      ~Term.get_species
      ~Term.iterate_obo_lines
      ~Term.iterate_properties
      ~Term.iterate_relations
      ~Term.set_species

   .. rubric:: Attributes Documentation

   .. autoattribute:: definition
   .. autoattribute:: is_obsolete
   .. autoattribute:: namespace

   .. rubric:: Methods Documentation

   .. automethod:: append_alt
   .. automethod:: append_comment
   .. automethod:: append_exact_match
   .. automethod:: append_parent
   .. automethod:: append_property
   .. automethod:: append_provenance
   .. automethod:: append_relationship
   .. automethod:: append_see_also
   .. automethod:: append_synonym
   .. automethod:: append_xref
   .. automethod:: auto
   .. automethod:: extend_parents
   .. automethod:: extend_relationship
   .. automethod:: from_curie
   .. automethod:: from_triple
   .. automethod:: get_properties
   .. automethod:: get_property
   .. automethod:: get_relationship
   .. automethod:: get_relationships
   .. automethod:: get_species
   .. automethod:: iterate_obo_lines
   .. automethod:: iterate_properties
   .. automethod:: iterate_relations
   .. automethod:: set_species
